/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#include <qpe/qpemenubar.h>
#include <qpe/config.h>
#include <qapplication.h>
#include <qmainwindow.h>
#include <qpopupmenu.h>
#include <qtimer.h>
#include "PlayField.h"
#include "Icebloxx.h"
#include <stdlib.h>
#include <time.h>

Icebloxx::Icebloxx(QWidget *parent, const char *name, WFlags f) :
    QMainWindow(parent, name, f)
{
    /* initialize random number generator */
    srand(::time(0));

    /* set windows style and caption */
    setCaption("Icebloxx");

    /* create the play field as the central widget */
    m_field = new PlayField(this);
    setCentralWidget(m_field);
    m_field->show();

    /* create the game/speed submenu */
    m_speedMenu = new QPopupMenu(0, "speed_menu");
    connect(m_speedMenu, SIGNAL(activated(int)), this, SLOT(updateSpeed(int)));
    connect(m_speedMenu, SIGNAL(activated(int)), m_field, SLOT(updateSpeed(int)));
    m_speedMenu->setCheckable(true);
    m_speedMenu->insertItem(tr("Normal"), 6);
    m_speedMenu->insertItem(tr("Fast"), 9);
    m_speedMenu->insertItem(tr("Roadrunner"), 12);

    /* create the game/strength submenu */
    m_strengthMenu = new QPopupMenu(0, "strength_menu");
    connect(m_strengthMenu, SIGNAL(activated(int)), this, SLOT(updateStrength(int)));
    connect(m_strengthMenu, SIGNAL(activated(int)), m_field, SLOT(updateStrength(int)));
    m_strengthMenu->setCheckable(true);
    m_strengthMenu->insertItem(tr("Weakling"), 6);
    m_strengthMenu->insertItem(tr("Normal"), 12);
    m_strengthMenu->insertItem(tr("Strong"), 18);
    m_strengthMenu->insertItem(tr("SuperTux"), 24);

    /* create the game/coins submenu */
    m_coinsMenu = new QPopupMenu(0, "coins_menu");
    connect(m_coinsMenu, SIGNAL(activated(int)), this, SLOT(updateCoins(int)));
    connect(m_coinsMenu, SIGNAL(activated(int)), m_field, SLOT(updateCoins(int)));
    m_coinsMenu->setCheckable(true);
    m_coinsMenu->insertItem(tr("3"), 3);
    m_coinsMenu->insertItem(tr("4"), 4);
    m_coinsMenu->insertItem(tr("5"), 5);
    m_coinsMenu->insertItem(tr("6"), 6);
    m_coinsMenu->insertItem(tr("7"), 7);
    m_coinsMenu->insertItem(tr("8"), 8);

    /* create the game submenu */
    QPopupMenu *gameMenu = new QPopupMenu(0, "game_menu");
    gameMenu->insertItem(tr("New"), m_field, SLOT(start()));
    gameMenu->insertItem(tr("Speed"), m_speedMenu);
    gameMenu->insertItem(tr("Strength"), m_strengthMenu);
    gameMenu->insertItem(tr("Coins"), m_coinsMenu);
    gameMenu->insertSeparator();
    gameMenu->insertItem(tr("Close"), this, SLOT(close()));

    /* create the menu */
    QPEMenuBar *menu = new QPEMenuBar(this);
    menu->insertItem(tr("Game"), gameMenu);

    /* read the configuration file */
    readConfig();

    /* check the menu entries of game submenus */
    m_speedMenu->setItemChecked(m_speed, true);
    m_strengthMenu->setItemChecked(m_strength, true);
    m_coinsMenu->setItemChecked(m_coins, true);
}

Icebloxx::~Icebloxx()
{
    writeConfig();
}

void Icebloxx::readConfig(void)
{
    Config cfg("Icebloxx");

    cfg.setGroup("Settings");

    int speed = cfg.readNumEntry("Speed", 6);
    if (speed <= 6) {
	m_speed = 6;
    } else if (speed <= 9) {
	m_speed = 9;
    } else {
	m_speed = 12;
    }
    m_field->updateSpeed(m_speed);

    int strength = cfg.readNumEntry("Strength", 12);
    if (strength <= 6) {
	m_strength = 6;
    } else if (strength <= 12) {
	m_strength = 12;
    } else if (strength <= 18) {
	m_strength = 18;
    } else {
	m_strength = 24;
    }
    m_field->updateStrength(m_strength);

    int coins = cfg.readNumEntry("Coins", 5);
    if (coins < 3) {
	m_coins = 3;
    } else if (coins > 8) {
	m_coins = 8;
    } else {
	m_coins = coins;
    }
    m_field->updateCoins(m_coins);
}

void Icebloxx::writeConfig(void)
{
    Config cfg("Icebloxx");

    cfg.setGroup("Settings");
    cfg.writeEntry("Speed", m_speed);
    cfg.writeEntry("Strength", m_strength);
    cfg.writeEntry("Coins", m_coins);
}

void Icebloxx::updateSpeed(int speed)
{
    m_speedMenu->setItemChecked(m_speed, false);
    m_speed = speed;
    m_speedMenu->setItemChecked(m_speed, true);
    writeConfig();
}

void Icebloxx::updateStrength(int strength)
{
    m_strengthMenu->setItemChecked(m_strength, false);
    m_strength = strength;
    m_strengthMenu->setItemChecked(m_strength, true);
    writeConfig();
}

void Icebloxx::updateCoins(int coins)
{
    m_coinsMenu->setItemChecked(m_coins, false);
    m_coins = coins;
    m_coinsMenu->setItemChecked(m_coins, true);
    writeConfig();
}

