/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#ifndef __PLAYFIELD_HEADER__
#define __PLAYFIELD_HEADER__

#include <qwidget.h>
#include <qpixmap.h>
#include <qtimer.h>
#include "SpriteCollection.h"

class PlayField : public QWidget
{
    Q_OBJECT

public:
    PlayField(QWidget *parent, const char *name = 0, WFlags f = 0);
    ~PlayField();

private:
    static const int max_lives = 6;
    static const int max_flames = 4;
    static const int max_blocks = 17;
    static const int max_walls = 10;
    static const int max_actors = max_flames + max_blocks + max_walls + 1;
    static const int max_cols = 8;
    static const int max_rows = 8;
    static const int max_config = 6;
    enum Types {
	Empty = 0,
	Player,
	Block,
	BlockCoin,
	Flame,
	Points,
	Wall,
    };
    enum Directions {
	Stop = 0,
	Up,
	Down,
	Left,
	Right,
    };

private:
    SpriteCollection *m_sprites;
    QTimer *m_timer;
    QPixmap *m_pixmap;
    int m_speed;
    int m_strength;
    int m_coins;
    enum {
	Intro_1,
	Intro_2,
	Intro_3,
	Playing,
	Dying,
	HappyPenguin,
	GameOver,
    } m_state;
    int m_counter;
    int m_score;
    int m_lives;
    int m_levels_completed;
    int m_blocks_broken;
    int m_coins_collected;
    int m_flames_killed;
    struct {
	int m_x;
	int m_y;
	enum Directions m_act_dir;
	enum Directions m_req_dir;
	int m_speed;
	int m_counter;
	enum Types m_type;
    } m_actor[max_actors];
    int m_actors;
    int m_coins_in_level;
    int m_click_x;
    int m_click_y;
#ifdef CAN_TELEPORT
    bool m_teleport;
#endif

public slots:
    void updateSpeed(int speed);
    void updateStrength(int strength);
    void updateCoins(int coins);
    void start(void);
    void stop(void);
    void timerTick(void);

protected:
    void paintEvent(QPaintEvent *event);
    void showEvent(QShowEvent *event);
    void hideEvent(QHideEvent *event);
    void resizeEvent(QResizeEvent *event);
    void keyPressEvent(QKeyEvent *event);
    void keyReleaseEvent(QKeyEvent *event);
    void mousePressEvent(QMouseEvent *event);

private:
    void drawIntro_1(void);
    void drawIntro_2(void);
    void drawIntro_3(void);
    void drawField(void);
    void drawGameOver(void);
    void makeField(void);
    void check_field(enum Types map[max_rows][max_cols],
	bool visible[max_rows][max_cols], int row, int col);
    bool isFieldOk(void);
    void clearField(void);
    void animateActors(void);
    void moveActors(void);
    void recreateFlames(void);
    void recreatePlayer(void);
    void killFlame(int actor);
    void killPlayer(void);
    void moveOrCrushBlock(int actor, enum Directions dir);
#ifdef CAN_TELEPORT
    void teleport(void);
#endif
    int detectCollision(int actor, int x, int y);
    int detectCollisionMovingBlock(int actor, int x, int y);
    int detectCollisionBlockOrWall(int actor, int x, int y);
    int detectCollisionFlame(int actor, int x, int y);
    int detectCollisionPlayer(int x, int y);
    int detectCollisionWall(int actor, int x, int y);
    bool hasReachedClickPosition(int x, int y);
    bool lineOfSight(int actor1, int actor2, enum Directions dir);
    void dump(const char *file, const char *function, int line);
};

#endif // __PLAYFIELD_HEADER__

