/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#include <qwidget.h>
#include <qpixmap.h>
#include <qbitmap.h>
#include <qimage.h>
#include <qpainter.h>
#include "SpriteCollection.h"
#include "images/data.c"

SpriteCollection::SpriteCollection(QWidget *parent)
{
    m_parent = parent;
    m_block[0].loadFromData(block1_data_, sizeof (block1_data_));
    m_block[1].loadFromData(block2_data_, sizeof (block2_data_));
    m_block[2].loadFromData(block3_data_, sizeof (block3_data_));
    m_block[3].loadFromData(block4_data_, sizeof (block4_data_));
    m_block[4].loadFromData(block5_data_, sizeof (block5_data_));
    m_block[5].loadFromData(block6_data_, sizeof (block6_data_));
    m_block[6].loadFromData(block7_data_, sizeof (block7_data_));
    m_block[7].loadFromData(block8_data_, sizeof (block8_data_));
    m_block_coin[0].loadFromData(block_coin1_data_, sizeof (block_coin1_data_));
    m_block_coin[1].loadFromData(block_coin2_data_, sizeof (block_coin2_data_));
    m_block_coin[2].loadFromData(block_coin3_data_, sizeof (block_coin3_data_));
    m_block_coin[3].loadFromData(block_coin4_data_, sizeof (block_coin4_data_));
    m_block_coin[4].loadFromData(block_coin5_data_, sizeof (block_coin5_data_));
    m_block_coin[5].loadFromData(block_coin6_data_, sizeof (block_coin6_data_));
    m_block_coin[6].loadFromData(block_coin7_data_, sizeof (block_coin7_data_));
    m_block_coin[7].loadFromData(block_coin8_data_, sizeof (block_coin8_data_));
    m_coin.loadFromData(coin_data_, sizeof (coin_data_));
    m_coin.setMask(m_coin.createHeuristicMask());
    m_dead[0].loadFromData(dead1_data_, sizeof (dead1_data_));
    m_dead[1].loadFromData(dead2_data_, sizeof (dead2_data_));
    m_dead[2].loadFromData(dead3_data_, sizeof (dead3_data_));
    m_dead[3].loadFromData(dead4_data_, sizeof (dead4_data_));
    m_dead[4].loadFromData(dead5_data_, sizeof (dead5_data_));
    m_dead[5].loadFromData(dead6_data_, sizeof (dead6_data_));
    m_dead[6].loadFromData(dead7_data_, sizeof (dead7_data_));
    m_dead[7].loadFromData(dead8_data_, sizeof (dead8_data_));
    m_flame[0].loadFromData(flame1_data_, sizeof (flame1_data_));
    m_flame[1].loadFromData(flame2_data_, sizeof (flame2_data_));
    m_flame[2].loadFromData(flame3_data_, sizeof (flame3_data_));
    m_flame[3].loadFromData(flame4_data_, sizeof (flame4_data_));
    m_flame[4].loadFromData(flame5_data_, sizeof (flame5_data_));
    m_flame[0].setMask(m_flame[0].createHeuristicMask());
    m_flame[1].setMask(m_flame[1].createHeuristicMask());
    m_flame[2].setMask(m_flame[2].createHeuristicMask());
    m_flame[3].setMask(m_flame[3].createHeuristicMask());
    m_flame[4].setMask(m_flame[4].createHeuristicMask());
    m_happy_penguin.loadFromData(happy_penguin_data_, sizeof (happy_penguin_data_));
    m_intro.loadFromData(intro_data_, sizeof (intro_data_));
    m_live.loadFromData(live_data_, sizeof (live_data_));
    m_penguin.loadFromData(penguin_data_, sizeof (penguin_data_));
    m_penguin_up[0].loadFromData(penguin_up1_data_, sizeof (penguin_up1_data_));
    m_penguin_up[1].loadFromData(penguin_up2_data_, sizeof (penguin_up2_data_));
    m_penguin_up[2].loadFromData(penguin_up3_data_, sizeof (penguin_up3_data_));
    m_penguin_down[0].loadFromData(penguin_down1_data_, sizeof (penguin_down1_data_));
    m_penguin_down[1].loadFromData(penguin_down2_data_, sizeof (penguin_down2_data_));
    m_penguin_down[2].loadFromData(penguin_down3_data_, sizeof (penguin_down3_data_));
    m_penguin_left[0].loadFromData(penguin_left1_data_, sizeof (penguin_left1_data_));
    m_penguin_left[1].loadFromData(penguin_left2_data_, sizeof (penguin_left2_data_));
    m_penguin_left[2].loadFromData(penguin_left3_data_, sizeof (penguin_left3_data_));
    m_penguin_right[0].loadFromData(penguin_right1_data_, sizeof (penguin_right1_data_));
    m_penguin_right[1].loadFromData(penguin_right2_data_, sizeof (penguin_right2_data_));
    m_penguin_right[2].loadFromData(penguin_right3_data_, sizeof (penguin_right3_data_));
    m_points[0].loadFromData(points1_data_, sizeof (points1_data_));
    m_points[1].loadFromData(points2_data_, sizeof (points2_data_));
    m_points[0].setMask(m_points[0].createHeuristicMask());
    m_points[1].setMask(m_points[1].createHeuristicMask());
    m_wall.loadFromData(wall_data_, sizeof (wall_data_));
}

void SpriteCollection::drawBlock(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_block[state]);
}

void SpriteCollection::drawBlockCoin(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_block_coin[state]);
}

void SpriteCollection::drawCoin(QPainter &painter, int x, int y)
{
    painter.drawPixmap(x, y, m_coin);
}

void SpriteCollection::drawDead(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_dead[state]);
}

void SpriteCollection::drawFlame(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_flame[(state > 4) ? 8 - state : state]);
}

void SpriteCollection::drawHappyPenguin(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, state ? m_happy_penguin : m_penguin);
}

void SpriteCollection::drawIntro(QPainter &painter, int x, int y)
{
    painter.drawPixmap(x, y, m_intro);
}

void SpriteCollection::drawLive(QPainter &painter, int x, int y)
{
    painter.drawPixmap(x, y, m_live);
}

void SpriteCollection::drawPenguin(QPainter &painter, int x, int y)
{
    painter.drawPixmap(x, y, m_penguin);
}

void SpriteCollection::drawPenguinUp(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_penguin_up[(state > 2) ? 4 - state : state]);
}

void SpriteCollection::drawPenguinDown(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_penguin_down[(state > 2) ? 4 - state : state]);
}

void SpriteCollection::drawPenguinLeft(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_penguin_left[(state > 2) ? 4 - state : state]);
}

void SpriteCollection::drawPenguinRight(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_penguin_right[(state > 2) ? 4 - state : state]);
}

void SpriteCollection::drawPoints(QPainter &painter, int x, int y, int state)
{
    painter.drawPixmap(x, y, m_points[state]);
}

void SpriteCollection::drawWall(QPainter &painter, int x, int y)
{
    painter.drawPixmap(x, y, m_wall);
}

